@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 
 
-__version__ = "0.10"
+__version__ = "0.1.3"
 __author__ = [
     "Brian Ray <brianhray@gmail.com>",
 ]
@@ -10,10 +10,12 @@ __license__ = "TBD"
 from document_base import *
 import config_base
 import model_base
+import logging
+logging.basicConfig()
+
 
 Date = model_base.DateFieldType
 URL = model_base.URLFieldType
 Image = model_base.ImageFieldType
 
 Config = config_base.ConfigBase
-
